@@ -968,6 +968,23 @@ module Test
                          sub_test_method_names,
                        ])
         end
+
+        def test_base64_special_character
+          test_case = Class.new(TestCase) do
+          end
+          # ["array?"].pack("m") == "YXJyYXk/\n"
+          sub_test_case = test_case.sub_test_case("array?") do
+            def test_nothing
+            end
+          end
+
+          sub_test_method_names = sub_test_case.suite.tests.collect do |test|
+            test.method_name
+          end
+
+          assert_equal(["test_nothing"],
+                       sub_test_method_names)
+        end
       end
 
       class TestStartupShutdown < self
